==> blueprint-component-mapper-3.6.0.tgz: package/esm/date-picker/date-picker.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import { Popover } from "@blueprintjs/core/lib/esm/components/popover/popover.js";
import { Button } from "@blueprintjs/core/lib/esm/components/button/buttons.js";
import { DatePicker as BDatePicker } from '@blueprintjs/datetime';
import FormGroupWrapper from '../form-group/form-group';
import propsCatcher from '../props-catcher/props-catcher';

var DatePicker = function DatePicker(_ref) {
  var input = _ref.input,
      disabled = _ref.disabled,
      placeholder = _ref.placeholder,
      valueRenderer = _ref.valueRenderer,
      PopoverProps = _ref.PopoverProps,
      ButtonProps = _ref.ButtonProps,
      props = _objectWithoutProperties(_ref, ["input", "disabled", "placeholder", "valueRenderer", "PopoverProps", "ButtonProps"]);

  return /*#__PURE__*/React.createElement(Popover, _extends({
    disabled: disabled
  }, PopoverProps), /*#__PURE__*/React.createElement(Button, _extends({
    text: input.value ? valueRenderer(input.value) : placeholder,
    disabled: disabled
  }, ButtonProps)), /*#__PURE__*/React.createElement(BDatePicker, _extends({
    id: input.name
  }, propsCatcher(props), input, {
    value: input.value || null
  })));
};

DatePicker.defaultProps = {
  placeholder: 'Select date...',
  valueRenderer: function valueRenderer(value) {
    return value.toString();
  }
};
DatePicker.propTypes = {
  input: PropTypes.object,
  disabled: PropTypes.bool,
  placeholder: PropTypes.node,
  valueRenderer: PropTypes.func,
  PopoverProps: PropTypes.object,
  ButtonProps: PropTypes.object
};

var WrapperDatePicker = function WrapperDatePicker(props) {
  return /*#__PURE__*/React.createElement(FormGroupWrapper, _extends({}, props, {
    Component: DatePicker
  }));
};

export default WrapperDatePicker;

==> blueprint-component-mapper-3.18.4.tgz: package/esm/date-picker/date-picker.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "disabled", "placeholder", "valueRenderer", "PopoverProps", "ButtonProps"];
import React from 'react';
import PropTypes from 'prop-types';
import { Popover } from "@blueprintjs/core/lib/esm/components/popover/popover.js";
import { Button } from "@blueprintjs/core/lib/esm/components/button/buttons.js";
import { DatePicker as BDatePicker } from '@blueprintjs/datetime';
import FormGroupWrapper from '../form-group/form-group';
import propsCatcher from '../props-catcher/props-catcher';

var DatePicker = function DatePicker(_ref) {
  var input = _ref.input,
      disabled = _ref.disabled,
      placeholder = _ref.placeholder,
      valueRenderer = _ref.valueRenderer,
      PopoverProps = _ref.PopoverProps,
      ButtonProps = _ref.ButtonProps,
      props = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement(Popover, _extends({
    disabled: disabled
  }, PopoverProps), /*#__PURE__*/React.createElement(Button, _extends({
    text: input.value ? valueRenderer(input.value) : placeholder,
    disabled: disabled
  }, ButtonProps)), /*#__PURE__*/React.createElement(BDatePicker, _extends({
    id: input.name
  }, propsCatcher(props), input, {
    value: input.value || null
  })));
};

DatePicker.defaultProps = {
  placeholder: 'Select date...',
  valueRenderer: function valueRenderer(value) {
    return value.toString();
  }
};
DatePicker.propTypes = {
  input: PropTypes.object,
  disabled: PropTypes.bool,
  placeholder: PropTypes.node,
  valueRenderer: PropTypes.func,
  PopoverProps: PropTypes.object,
  ButtonProps: PropTypes.object
};

var WrapperDatePicker = function WrapperDatePicker(props) {
  return /*#__PURE__*/React.createElement(FormGroupWrapper, _extends({}, props, {
    Component: DatePicker
  }));
};

export default WrapperDatePicker;
